@@ -6,7 +6,6 @@
 """
 import os
 import time
-import tornado
 from threading import local
 from hashlib import sha1
 
@@ -14,6 +13,7 @@ from gridfs import GridFS
 from redis import Redis
 from pymongo import Connection
 from tornado.web import RequestHandler
+from tornado.websocket import WebSocketHandler
 import tornado.gen as gen
 try:
     import motor
@@ -26,9 +26,8 @@ session_id = lambda: sha1('%s%s' % (os.urandom(16), time.time())).hexdigest()
 class ContextHandler():
     def _execute(self, transforms, *args, **kwargs):
         with LogicContext():
-            #super(ContextHandler, self)._execute(transforms, *args, **kwargs)
-            if isinstance(self,tornado.websocket.WebSocketHandler):
-                tornado.websocket.WebSocketHandler._execute(self,transforms, *args, **kwargs)
+            if isinstance(self,WebSocketHandler):
+                WebSocketHandler._execute(self,transforms, *args, **kwargs)
             elif isinstance(self,RequestHandler):
                 RequestHandler._execute(self,transforms, *args, **kwargs)
 
@@ -44,6 +43,7 @@ class ContextHandler():
 class LogicContext(object):
     """
         logic context for mongodb and redis cache
+        如果不在上下文内，直接返回一个默认的上下文对象
     """
     _thread_local = local()
 
@@ -88,6 +88,9 @@ class LogicContext(object):
                                        network_timeout=__conf__.SOCK_TIMEOUT)
 
         return self._db_conn[name]
+    
+    def get_coll(self,name, dbname=None):
+        return get_mongo(dbname)[name]
 
     def get_async_mongo(self, name=None):
         """ 非阻塞的pympongo 支持，需要安装motor """
@@ -130,7 +133,7 @@ class LogicContext(object):
     @classmethod
     def get_context(cls):
         return hasattr(cls._thread_local, "contexts") and cls._thread_local.contexts and \
-            cls._thread_local.contexts[-1] or None
+            cls._thread_local.contexts[-1] or cls()
 
 
 get_context = LogicContext.get_context
